@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12131 2020-04-29 00:43:31Z Trista $
+# $Id: __init__.py 12132 2020-04-29 00:59:18Z Trista $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $ (last)
-# $Date: 2020-04-29 08:43:31 +0800 (週三, 29 四月 2020) $
-# $Revision: 12131 $
+# $Date: 2020-04-29 08:59:18 +0800 (週三, 29 四月 2020) $
+# $Revision: 12132 $
 
 from __future__ import print_function
 
@@ -425,7 +425,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
                 },
             }
 
-        _get = lambda k: settingsDict.get(k, dd[k])
+        _get = lambda k: settingsDict.get(k, dd.get(k, None))
 
         databaseDefaults = {
             'DATABASES': {
@@ -439,7 +439,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
                 },
             },
         }
-        if 'OPTIONS' in _get:
+        if _get('OPTIONS'):
             databaseDefaults['DATABASES']['default']['OPTIONS'] = _get('OPTIONS')
         databaseDefaults.update(dd)
 
