@@ -4,6 +4,7 @@ from __future__ import unicode_literals
 import importlib
 
 from django.db import migrations, models
+from django.db.utils import OperationalError
 
 
 def moveRedirectData(apps, schemaEditor):
@@ -15,17 +16,22 @@ def moveRedirectData(apps, schemaEditor):
     #Redirect = apps.get_model('contrib.redirects', 'Redirect')
     models = importlib.import_module('django.contrib.redirects.models')
     Redirect = getattr(models, 'Redirect')
+
+    try :
+        Redirect2 = apps.get_model('redirect', 'Redirect')
+        for r in Redirect.objects.all():
+            # ValueError: Cannot assign "<Site: 127.0.0.1:8000>": 
+            # "Redirect.site" must be a "Site" instance.
+            obj = Redirect2.objects.create(
+                site_id=r.site.id,
+                old_path=r.old_path,
+                new_path=r.new_path,
+            )
+            obj.save()
+    except OperationalError:
+        pass
     
-    Redirect2 = apps.get_model('redirect', 'Redirect')
-    for r in Redirect.objects.all():
-        # ValueError: Cannot assign "<Site: 127.0.0.1:8000>": 
-        # "Redirect.site" must be a "Site" instance.
-        obj = Redirect2.objects.create(
-            site_id=r.site.id,
-            old_path=r.old_path,
-            new_path=r.new_path,
-        )
-        obj.save()
+
 
 class Migration(migrations.Migration):
 
