@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11982 2020-03-19 11:39:46Z Lavender $
+# $Id: forms.py 12182 2020-05-07 07:28:10Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-03-19 19:39:46 +0800 (週四, 19 三月 2020) $
-# $Revision: 11982 $
+# $Date: 2020-05-07 15:28:10 +0800 (週四, 07 五月 2020) $
+# $Revision: 12182 $
 
 import os
 import re
@@ -269,8 +269,48 @@ catalogueViews.AttributeOptionGroupCreateUpdateView.form_invalid = \
 _ShippingAddressForm = get_class(
     'checkout.forms', 'ShippingAddressForm')
 Country = get_model('address', 'Country')
+
+# invoice
+DUPLICATE_UNIFORM_INVOICE = _("Duplicate Uniform Invoice")
+TRIPLICATE_UNIFORM_INVOICE = _("Triplicate Uniform Invoice")
+INVOICE_TYPE_CHOICES=(
+    (DUPLICATE_UNIFORM_INVOICE, DUPLICATE_UNIFORM_INVOICE),
+    (TRIPLICATE_UNIFORM_INVOICE, TRIPLICATE_UNIFORM_INVOICE),
+)
+
+IUNO_SHOP_INVOICE_ENABLE = getattr(settings, "IUNO_SHOP_INVOICE_ENABLE", False)
+
+class ShippingAddressForm1(_ShippingAddressForm):
+    if IUNO_SHOP_INVOICE_ENABLE:
+        taxId = forms.CharField(label=_("Tax ID"), required=False)
+        invoiceType = forms.CharField(
+            label=_("Invoice type"), required=False, 
+            widget=forms.Select(choices=INVOICE_TYPE_CHOICES), initial=DUPLICATE_UNIFORM_INVOICE)
+        companyName = forms.CharField(label=_("Company name"), required=False)
+        
+    class Meta(_ShippingAddressForm.Meta):
+        if IUNO_SHOP_INVOICE_ENABLE:
+            index = _ShippingAddressForm.Meta.fields.index("notes")
+            fields = _ShippingAddressForm.Meta.fields
+            for f in reversed(['invoiceType', 'taxId', 'companyName',]): # reverse 是為了讓 list 欄位順序與實際表單一致
+                fields.insert(index, f)
+        else:
+            fields = _ShippingAddressForm.Meta.fields
+            
+    def clean_notes(self):
+        data = self.cleaned_data['notes']
+        if IUNO_SHOP_INVOICE_ENABLE:
+            taxId = self.cleaned_data.get("taxId", "")
+            invoiceType = self.cleaned_data.get("invoiceType", "")
+            companyName = self.cleaned_data.get("companyName", "")
+            
+            if invoiceType == DUPLICATE_UNIFORM_INVOICE:
+                data += _("\nInvoice type: %s") % (invoiceType,)
+            else:
+                data += _("\nInvoice type: %s\nTax ID: %s\nCompany name: %s") % (invoiceType, taxId, companyName)
+        return data
     
-class ShippingAddressForm2(_ShippingAddressForm):
+class ShippingAddressForm2(ShippingAddressForm1):
     ordererFirstName = forms.CharField(
         label=_('Orderer first name'), required=True)
     ordererLastName = forms.CharField(
@@ -285,12 +325,13 @@ class ShippingAddressForm2(_ShippingAddressForm):
     )
     ordererPostcode = forms.CharField(
         label=_('Orderer postcode'), required=True)
+    
+    class Meta(ShippingAddressForm1.Meta):
         
-    class Meta(_ShippingAddressForm.Meta):
         fields = [
             'ordererFirstName', 'ordererLastName', 'ordererLine1', 
             'ordererLine4', 'ordererCountry', 'ordererPostcode',
-        ] + _ShippingAddressForm.Meta.fields
+        ] + ShippingAddressForm1.Meta.fields
   
     def clean_odererPostcode(self):
         data = self.cleaned_data['ordererPostcode']
@@ -330,7 +371,7 @@ def get_form(self, **kwargs):
     if (self.request.user.is_authenticated and 
         not OrdererAddress.objects.filter(user=self.request.user).exists()):
         return ShippingAddressForm2(**self.get_form_kwargs())
-    return form
+    return ShippingAddressForm1(**self.get_form_kwargs())
  
 _getValid =  checkoutViews.ShippingAddressView.form_valid
 
