@@ -21,7 +21,7 @@ from Iuno.test import RemoteTestCaseMixin
 class TestOscarDemo(TestCase, RemoteTestCaseMixin):
     
     TEST_URL = "http://127.0.0.1:8000"
-    TEST_SETTINGS = "tests.TestSettings"
+    TEST_SETTINGS = "OscarDemo.TestSettings"
         
 
 if __name__ == "__main__":
